@@ -17,12 +17,12 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
       xy <- aperm(xy, c(1,3,2,4))
       dim(xy) <- c(sc*gc, gr*sr)
       xy}
-  quantile.na <- function (z, ...) 
+  quantile.na <- function (z, ...)
     {
       tmp <- !(is.na(z) | is.infinite(z))
       quantile(z[tmp], ...)
     }
-  length.na <- function (z, ...) 
+  length.na <- function (z, ...)
     {
       tmp <- !(is.na(z) | is.infinite(z))
       length(z[tmp], ...)
@@ -47,11 +47,11 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
     }
     par(xpd=FALSE)
   }
-  if (crit1 >= 1) 
+  if (crit1 >= 1)
     crit1 <- crit1/(length.na(z))
-  if (crit2 >= 1) 
+  if (crit2 >= 1)
     crit2 <- crit2/(length.na(z))
-  tmpind <- (z > quantile.na(z, probs = 1 - crit2)) | (z < 
+  tmpind <- (z > quantile.na(z, probs = 1 - crit2)) | (z <
                                   quantile.na(z, probs = crit1))
   n <- prod(unlist(layout))
   n.all <- length(z)
@@ -73,7 +73,7 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
     phi[-1] <- sapply(quiles2[-1],
                       function(x, z)sum(z<=x, na.rm=TRUE)/length.na(z), z=z)
   }
-  
+
   if(crit1+crit2<1){
     quiles <- c(quiles1,quiles2)
     frac <- c(plo, phi)
@@ -108,7 +108,8 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
   }
   else fullm[!tmpind] <- NA
   if ((length(as.vector(z)) != n) & (is.null(names(z)))) {
-    stop(" Error: Length of vector is different from total number of spots and vector has no row.name.\n")
+    stop(paste("Error: Length of vector is different from total number\n",
+               "of spots and vector has no row.name.\n"))
   }
 #################################################################
   gc <- layout$ngrid.c
@@ -116,7 +117,7 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
   sc <- layout$nspot.c
   sr <- layout$nspot.r
   full <- block2matrix(fullm, sr, sc, gr, gc)
-  image(1:ncol(full), 1:nrow(full), t(full), axes = FALSE, 
+  image(1:ncol(full), 1:nrow(full), t(full), axes = FALSE,
         xlab = "", ylab = "", col=colpal)
   box()
   abline(v = ((gr - 1):1) * (sr) + 0.5)
@@ -141,7 +142,7 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
     yvals2 <- seq(from=par()$usr[3], to=par()$usr[4],
                   length=n2+midbreak+2*nacat+1)[-(n2+midbreak+2*nacat+1)]
     eps2 <- diff(yvals2[1:2])
-    
+
     if(nacat){
       nlast <- length(yvals2)
       nclast <- length(colpal)
@@ -164,7 +165,7 @@ function (z=coralRG$R[,1], layout=coralRG$printer, crit1 = 0.05,
            srt=srt, xpd=TRUE, cex=0.65)
       text(xquilepos, yvals2[length(yvals2)]+eps2, "(100%)", srt=srt,
            xpd=TRUE, cex=0.65)
-      
+
     }
     else {rect(x0, yvals2[1:nhalf], x0+barwid, yvals2[1:nhalf]+eps2,
                col=colpal[1:nhalf], xpd=TRUE)
